@@ -169,6 +169,12 @@
       data.frame(.step = tuneSeq)
     }
 
+  roccTune <- function(data, len)
+    {
+      tmp <- rfTune(data, len)
+      names(tmp) <- ".xgenes"
+      tmp
+    }
   
   trainGrid <- switch(method,
                       nnet =, pcaNNet = expand.grid(
@@ -272,6 +278,10 @@
                         .cp = "bic", 
                         .lambda = c(0, 10 ^ seq(-1, -4, length = len - 1))),
                       GAMens = GAMensTune(data, len),
+                      rocc = roccTune(data, len),
+                      foba = expand.grid(
+                        .lambda = 10 ^ seq(-5, -1, length = len),
+                        .k = larsTune(data, len)[,1]),
                       lda =, lm =, treebag =, sddaLDA =, sddaQDA =,
                       glm =, qda =, OneR =, rlm =,
                       rvmLinear =, lssvmLinear =, gaussprLinear =,
